==> haskell-path-io-1.6.2-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-io
version:              1.6.2
visibility:           public
id:                   path-io-1.6.2-884QcY5MJUl986LtZVKcRe
key:                  path-io-1.6.2-884QcY5MJUl986LtZVKcRe
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  487a31968ed730db0bd72a69bcf09125
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-8.10.3/site-local/path-io-1.6.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/path-io-1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/path-io-1.6.2
hs-libraries:         HSpath-io-1.6.2-884QcY5MJUl986LtZVKcRe
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    dlist-1.0-8lf2wgAIOQZ603aeYRXCBo exceptions-0.10.4 filepath-1.4.2.1
    path-0.8.0-GuXugUy2tjbGKDIATQUc8D
    temporary-1.3-1IMBkjh3EgS7aRRZacwYZg time-1.9.3
    transformers-0.5.6.2 unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.6.2-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-io
version:              1.6.2
visibility:           public
id:                   path-io-1.6.2-6Tkk5cdCLwiBF3KZPQW5Zt
key:                  path-io-1.6.2-6Tkk5cdCLwiBF3KZPQW5Zt
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  dbdff7b8b01b30a901a7be2818d4f521
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-8.10.3/site-local/path-io-1.6.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/path-io-1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/path-io-1.6.2
hs-libraries:         HSpath-io-1.6.2-6Tkk5cdCLwiBF3KZPQW5Zt
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    dlist-1.0-2DyQ8IrsVeM5gI3RL38aSQ exceptions-0.10.4 filepath-1.4.2.1
    path-0.8.0-DkZyv3iA8Gi6SEGjo8IooX
    temporary-1.3-HSi6zDu4rXQPDXDBHna7q time-1.9.3 transformers-0.5.6.2
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
